@@ -26,9 +26,8 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 import java.util.stream.Collectors;
 
-import javax.ws.rs.RuntimeType;
-import javax.ws.rs.core.Configuration;
-
+import jakarta.ws.rs.RuntimeType;
+import jakarta.ws.rs.core.Configuration;
 import org.apache.cxf.Bus;
 import org.apache.cxf.BusFactory;
 import org.apache.cxf.common.classloader.ClassLoaderUtils;
@@ -149,7 +148,7 @@ public final class MicroProfileClientProviderFactory extends ProviderFactory {
                 .getContextualProperty(Configuration.class.getName());
     }
 
-    private class ResponseExceptionMapperComparator implements Comparator<ResponseExceptionMapper<?>> {
+    private final class ResponseExceptionMapperComparator implements Comparator<ResponseExceptionMapper<?>> {
 
         @Override
         public int compare(ResponseExceptionMapper<?> oLeft, ResponseExceptionMapper<?> oRight) {
